// webpack.config.cjs
const path = require('path');
const webpack = require('webpack');

const commonConfig = {
  entry: './index.js', // Point d'entrée de votre application
  output: {
    filename: 'openapisnippet.min.js', // Nom du fichier de sortie
    path: path.resolve(__dirname, 'dist'), // Répertoire de sortie
  },
  resolve: {
    alias: { process: 'process/browser' },
    fallback: {
      stream: require.resolve('stream-browserify'),
      buffer: require.resolve('buffer/'),
      url: require.resolve('url/'),
      querystring: require.resolve('querystring-es3'),
      path: require.resolve("path-browserify"),
      util: require.resolve("util/"),
      https: require.resolve("https-browserify"),
      http: require.resolve("stream-http"),
      fs: false,
    },
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        use: {
          loader: 'babel-loader', // Utiliser Babel pour transpiler le code
          options: {
            targets: 'defaults',
            presets: [['@babel/preset-env']],
          },
        },
      },
    ],
  },
  plugins: [
    new webpack.ProvidePlugin({
      OpenAPISnippets: './index.js', // Exposer OpenAPISnippets en tant que variable globale
      process: 'process/browser',
    }),
  ],
  // mode: 'production', // Mode production pour minifier le code
  devtool: 'source-map',
};

const minifiedConfig = {
  ...commonConfig,
  output: {
    filename: 'openapisnippet.min.js', // Nom du fichier minifié
    path: path.resolve(__dirname, 'dist'), // Répertoire de sortie
  },
  mode: 'production', // Mode production pour minifier le code
};

const nonMinifiedConfig = {
  ...commonConfig,
  output: {
    filename: 'openapisnippet.js', // Nom du fichier non minifié
    path: path.resolve(__dirname, 'dist'), // Répertoire de sortie
  },
  mode: 'development', // Mode développement pour ne pas minifier le code
  optimization: {
    minimize: false, // Désactiver la minification
  },
};

module.exports = [minifiedConfig, nonMinifiedConfig];
